@@ -1,9 +1,6 @@
 import sys, multiprocessing, ctypes
 import tkinter as tk
-try:
-    from main_application import Application
-except ModuleNotFoundError:
-    from ANYstructure.main_application import Application
+from any_files.main_application import Application
 
 def main(args=None):
     """The main routine."""
@@ -23,7 +20,4 @@ def main(args=None):
     # you want your project to do.
 
 if __name__ == "__main__":
-    try:
-        main()
-    except ImportError:
-        ANYstructure.main()
+    main()
